<?php if (!defined('ABSPATH')) die;

function switch_to_new_instagram_api_twentytwenty() {
	
	$switched = get_option('p3_new_ig_twentytwenty_switched');
	if ($switched) {
		return;
	}
	
	if (get_option('pipdig_instagram')) {
		update_option('p3_new_ig_twentytwenty_show', 1);
	}
	
	delete_option('pipdig_instagram');
	
	$smash = get_option('sb_instagram_settings');
	if (!empty($smash['connected_accounts']) && is_array($smash['connected_accounts'])) {
		$first_account = reset($smash['connected_accounts']);
		if (!empty($first_account['access_token']) && !empty($first_account['user_id'])) {
			$access_token = sanitize_text_field($first_account['access_token']);
			$user_id = sanitize_text_field($first_account['user_id']);
			$instagram_deets = array(
				'access_token' => $access_token,
				'user_id' => $user_id,
			);
			update_option('pipdig_instagram', $instagram_deets);
			delete_option('p3_new_ig_twentytwenty_show');
		}
	}
	
	update_option('p3_new_ig_twentytwenty_switched', 1);
	
}
add_action('admin_init', 'switch_to_new_instagram_api_twentytwenty');


function switch_to_new_instagram_api_twentytwenty_notice() {
	
	if (!current_user_can('manage_options')) {
		return;
	}
	
	if (!get_option('p3_new_ig_twentytwenty_show')) {
		return;
	}

	if (isset($_POST['p3_new_ig_twentytwenty_dismiss'])) {
		delete_option('p3_new_ig_twentytwenty_show');
		return;
	}

	?>
	<div class="notice notice-error" id="p3_new_ig_twentytwenty_notice">
		<h2><span class="dashicons dashicons-warning"></span> Action required</h2>
		<p>Your Instagram access token has expired. Please go to <a href="<?php echo admin_url('admin.php?page=pipdig-instagram'); ?>">this page</a> to re-connect your account.</p>
		<p>Instagram has made some changes to their system which means that the Likes and Comment counts are no longer available. Please see <a href="https://www.pipdig.co/blog/upcoming-changes-to-the-instagram-api/" target="_blank" rel="noopener">this post</a> for more information.</p>
		<form action="" method="post">
			<input type="hidden" value="true" name="p3_new_ig_twentytwenty_dismiss" />
			<p class="submit" style="margin-top: 5px; padding-top: 5px;">
				<input name="submit" class="button" value="Hide this notice" type="submit" />
			</p>
		</form>
	</div>
	<?php
}
add_action('admin_notices', 'switch_to_new_instagram_api_twentytwenty_notice');


// Refresh long-lived access token on page loads every 7 days or longer
function p3_refresh_ig_access_token($access_token = '') {

	if (empty($access_token)) {
		$instagram_deets = get_option('pipdig_instagram');
		if (empty($instagram_deets['access_token'])) {
			return;
		}
		$access_token = sanitize_text_field($instagram_deets['access_token']);
	}
	
	$transient_id = substr($access_token, 0, 10);
	
	if (!get_transient('p3_insta_ref_'.$transient_id)) {
		$url = 'https://graph.instagram.com/refresh_access_token?grant_type=ig_refresh_token&access_token='.$access_token;
		$args = array('timeout' => 5);
		wp_remote_get($url, $args);
		set_transient('p3_insta_ref_'.$transient_id, '1', 3 * DAY_IN_SECONDS);
	}
	
}


// function to fetch images
function p3_instagram_fetch($access_token = '', $user_id = '') {
	
	$instagram_deets = get_option('pipdig_instagram');
	
	if (empty($access_token)) {
		if (empty($instagram_deets['access_token'])) {
			return array();
		}
		$access_token = sanitize_text_field($instagram_deets['access_token']);
	}
	
	if (empty($user_id)) {
		p3_refresh_ig_access_token($access_token);
	}
	
	if (empty($user_id)) {
		if (!empty($instagram_deets['user_id'])) {
			$user_id = sanitize_text_field($instagram_deets['user_id']);
		}
	}
	
	$transient_id = substr($access_token, 0, 10).$user_id;
	
	if (false === ($images = get_transient('p3_insta_'.$transient_id))) {
		
		if ($user_id) {
			$url = 'https://graph.facebook.com/'.$user_id.'/media?fields=id,media_type,media_url,permalink,like_count,comments_count,thumbnail_url&access_token='.$access_token;
		} else {
			$url = 'https://graph.instagram.com/me/media?fields=id,media_type,media_url,permalink,thumbnail_url&access_token='.$access_token;
		}
		
		$args = array('timeout' => 15);
		$response = wp_remote_retrieve_body(wp_remote_get($url, $args));
		
		if (empty($response)) {
			return array();
		}
		
		$result = json_decode($response);
		
		if (!isset($result->data) || !is_array($result->data)) {
			return array();
		}

		$images = array();

		foreach ($result->data as $item) {
			
			if (!empty($item->thumbnail_url)) {
				$img = $item->thumbnail_url;
			} elseif (!empty($item->media_url)) {
				$img = $item->media_url;
			} else {
				continue;
			}
			
			$data = array(
				'src' => $img,
				'src_low' => $img,
				'link' => $item->permalink,
				'caption' => '',
			);
			if (isset($item->like_count)) {
				$data['likes'] = absint($item->like_count);
			}
			if (isset($item->comments_count)) {
				$data['comments'] = absint($item->comments_count);
			}
			$images[] = $data;
		}
		
		// Get next page too
		if (!empty($result->paging->next)) {
			$response = wp_remote_retrieve_body(wp_safe_remote_get($result->paging->next, $args));
			if ($response) {
				$result = json_decode($response);
				if (!isset($result->data) || !is_array($result->data)) {
					foreach ($result->data as $item) {
						
						if (!empty($item->thumbnail_url)) {
							$img = $item->thumbnail_url;
						} elseif (!empty($item->media_url)) {
							$img = $item->media_url;
						} else {
							continue;
						}
						
						$data = array(
							'src' => $img,
							'src_low' => $img,
							'link' => $item->permalink,
							'caption' => '',
						);
						if (isset($item->like_count)) {
							$data['likes'] = absint($item->like_count);
						}
						if (isset($item->comments_count)) {
							$data['comments'] = absint($item->comments_count);
						}
						$images[] = $data;
					}
				}
			}
		}

		set_transient('p3_insta_'.$transient_id, $images, 30 * MINUTE_IN_SECONDS);
	}
	
	if ($images) {
		return $images;
	} else {
		return array();
	}

}
add_action('login_footer', 'p3_instagram_fetch', 99); // push on login page to avoid cache


// add css to head depending on amount of images displayed
function p3_instagram_css_to_head($width) {
	if (get_theme_mod('p3_instagram_header') || get_theme_mod('p3_instagram_footer') || get_theme_mod('p3_instagram_kensington') || get_theme_mod('p3_instagram_above_posts_and_sidebar')) {
		$num = absint(get_theme_mod('p3_instagram_number', 8));
		$width = 100 / $num;
		?>
		<!--noptimize-->
		<style>
		.p3_instagram_post{width:<?php echo $width; ?>%}
		<?php if(!get_theme_mod('disable_responsive')) { ?>
		@media only screen and (max-width: 719px) {
			.p3_instagram_post {
				width: 25%;
			}
		}
		<?php } ?>
		</style>
		<!--/noptimize-->
		<?php
	}
}
add_action('wp_head', 'p3_instagram_css_to_head');


// footer feed
function p3_instagram_footer() {

	if (!get_theme_mod('p3_instagram_footer')) {
		return;
	}

	$access_token = apply_filters('p3_instagram_footer_access_token', '');
	/*
	add_filter('p3_instagram_footer_access_token', function() {
		return 'ACCESS_TOKEN_HERE';
	});
	*/
	
	$images = p3_instagram_fetch($access_token); // grab images

	if ($images) {

		$lazy = false;
		if (is_pipdig_lazy()) {
			$lazy = true;
		}

		$num = intval(get_theme_mod('p3_instagram_number', 8));
		if (get_theme_mod('p3_instagram_rows')) {
			$rows = apply_filters('p3_instagram_rows_number', 2);
			$num = $num*$rows;
		}
		$links = get_option('pipdig_links');
		if (!empty($links['instagram'])) {
			$instagram_url = esc_url($links['instagram']);
			if (filter_var($instagram_url, FILTER_VALIDATE_URL)) {  // url to path
				$instagram_user = parse_url($instagram_url, PHP_URL_PATH);
				$instagram_user = str_replace('/', '', $instagram_user);
			}
		}
	?>
		<div class="clearfix"></div>
		<div id="p3_instagram_footer">
			<?php if (!empty($instagram_url) && !empty($instagram_user) && get_theme_mod('p3_instagram_footer_title')) { ?>
				<div class="p3_instagram_footer_title_bar">
					<h3 class="p_post_titles_font"><a href="<?php echo $instagram_url; ?>" target="_blank" rel="nofollow noopener">Instagram <span style="text-transform:none">@<?php echo strip_tags($instagram_user); ?></span></a></h3>
				</div>
			<?php } ?>
			<?php $num = $num-1; ?>
			<?php for ($x = 0; $x <= $num; $x++) {
				if (!isset($images[$x]['link'])) {
					break;
				}
				$hide_class = '';
				if ($x >= 4) {
					$hide_class = ' p3_instagram_hide_mobile';
				}
				$image_src = 'style="background-image:url('.$images[$x]['src'].');"';
				if ($lazy) {
					$hide_class .= ' pipdig_lazy';
					$image_src = 'data-src="'.$images[$x]['src'].'"';
				}
				?>
				<a href="<?php echo $images[$x]['link']; ?>" id="p3_instagram_post_<?php echo $x; ?>" class="p3_instagram_post<?php echo $hide_class; ?>" <?php echo $image_src; ?> rel="nofollow noopener" target="_blank" aria-label="Instagram">
					<img src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABAQMAAAAl21bKAAAAA1BMVEUAAACnej3aAAAAAXRSTlMAQObYZgAAAApJREFUCNdjYAAAAAIAAeIhvDMAAAAASUVORK5CYII=" class="p3_instagram_square" alt=""/>
					<div class="p3_instagram_post_overlay">
						<?php if (get_theme_mod('p3_instagram_meta', 1) && !empty($images[$x]['likes'])) { ?>
							<span class="p3_instagram_likes"><i class="pipdigicons pipdigicons-comment"></i> <?php echo $images[$x]['comments']; ?> &nbsp;
							<i class="pipdigicons pipdigicons-heart"></i> <?php echo $images[$x]['likes']; ?></span>
						<?php } ?>
					</div>
				</a>
			<?php } ?>
			<div class="clearfix"></div>
		</div>
		<div class="clearfix"></div>
		<?php
	} else { // no access token or user id, so error for admins:
		if (current_user_can('manage_options')) {
			echo '<p style="text-align:center">Unable to display Instagram feed. Please check your account has been correctly setup on <a href="'.admin_url('admin.php?page=pipdig-instagram').'" style="color:red">this page</a>. This error can also occur if you have not yet published any images to Instagram or if your Instagram profile is set to Private. Only site admins can see this message.</p>';
		}
	}
}
add_action('p3_footer_bottom', 'p3_instagram_footer', 99);


// header feed
function p3_instagram_header() {

	if (!get_theme_mod('p3_instagram_header')) {
		return;
	}

	if (!get_theme_mod('p3_instagram_header_all') && (!is_front_page() && !is_home()) ) {
		return;
	}
	
	$access_token = apply_filters('p3_instagram_header_access_token', '');
	/*
	add_filter('p3_instagram_header_access_token', function() {
		return 'ACCESS_TOKEN_HERE';
	});
	*/
	
	$images = p3_instagram_fetch($access_token); // grab images

	if ($images) {
		$num = intval(get_theme_mod('p3_instagram_number', 8));
		if (get_theme_mod('p3_instagram_rows')) {
			$num = $num*2;
		}
	?>
		<div class="clearfix"></div>
		<div id="p3_instagram_header">
		<?php $num = $num-1; ?>
			<?php for ($x = 0; $x <= $num; $x++) {
				if (!isset($images[$x]['link'])) {
					break;
				}
				$hide_class = '';
				if ($x >= 4) {
					$hide_class = ' p3_instagram_hide_mobile';
				}
				?>
				<a href="<?php echo $images[$x]['link']; ?>" id="p3_instagram_post_<?php echo $x; ?>" class="p3_instagram_post<?php echo $hide_class; ?>" style="background-image:url(<?php echo $images[$x]['src']; ?>);" rel="nofollow noopener" target="_blank" aria-label="Instagram">
					<img src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABAQMAAAAl21bKAAAAA1BMVEUAAACnej3aAAAAAXRSTlMAQObYZgAAAApJREFUCNdjYAAAAAIAAeIhvDMAAAAASUVORK5CYII=" class="p3_instagram_square" alt=""/>
					<div class="p3_instagram_post_overlay">
						<?php if (get_theme_mod('p3_instagram_meta', 1) && !empty($images[$x]['likes'])) { ?>
							<span class="p3_instagram_likes"><i class="pipdigicons pipdigicons-comment"></i> <?php echo $images[$x]['comments']; ?> &nbsp;
							<i class="pipdigicons pipdigicons-heart"></i> <?php echo $images[$x]['likes']; ?></span>
						<?php } ?>
					</div>
				</a>
			<?php } ?>
			<div class="clearfix"></div>
		</div>
		<div class="clearfix"></div>
		<?php
	} else { // no access token or user id, so error for admins:
		if (current_user_can('manage_options')) {
			echo '<p style="text-align:center">Unable to display Instagram feed. Please check your account has been correctly setup on <a href="'.admin_url('admin.php?page=pipdig-instagram').'" style="color:red">this page</a>. This error can also occur if you have not yet published any images to Instagram or if your Instagram profile is set to Private. Only site admins can see this message.</p>';
		}
	}
}
add_action('p3_top_site_main', 'p3_instagram_header', 99);


// above posts and sidebar
function p3_instagram_site_main_container() {

	if (!get_theme_mod('p3_instagram_above_posts_and_sidebar')) {
		return;
	}

	if (!is_front_page() && !is_home()) {
		return;
	}
	
	if (is_paged()) {
		return;
	}

	$images = p3_instagram_fetch(); // grab images

	if ($images) {
		$num = intval(get_theme_mod('p3_instagram_number', 8));
	?>
		<div class="clearfix"></div>
		<div id="p3_instagram_site_main_container">
		<h3 class="widget-title"><span>Instagram</span></h3>
		<?php $num = $num-1; ?>
			<?php for ($x = 0; $x <= $num; $x++) {
				if (!isset($images[$x]['link'])) {
					break;
				}
				$hide_class = '';
				if ($x >= 4) {
					$hide_class = ' p3_instagram_hide_mobile';
				}
				?>
				<a href="<?php echo $images[$x]['link']; ?>" id="p3_instagram_post_<?php echo $x; ?>" class="p3_instagram_post<?php echo $hide_class; ?>" style="background-image:url(<?php echo $images[$x]['src']; ?>);" rel="nofollow noopener" target="_blank" aria-label="Instagram">
					<img src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABAQMAAAAl21bKAAAAA1BMVEUAAACnej3aAAAAAXRSTlMAQObYZgAAAApJREFUCNdjYAAAAAIAAeIhvDMAAAAASUVORK5CYII=" class="p3_instagram_square" alt=""/>
					<div class="p3_instagram_post_overlay">
						<?php if (get_theme_mod('p3_instagram_meta', 1) && !empty($images[$x]['likes'])) { ?>
							<span class="p3_instagram_likes"><i class="pipdigicons pipdigicons-comment"></i> <?php echo $images[$x]['comments']; ?> &nbsp;
							<i class="pipdigicons pipdigicons-heart"></i> <?php echo $images[$x]['likes']; ?></span>
						<?php } ?>
					</div>
				</a>
			<?php } ?>
			<div class="clearfix"></div>
		</div>
		<div class="clearfix"></div>
		<?php
	} else { // no access token or user id, so error for admins:
		if (current_user_can('manage_options')) {
			echo '<p style="text-align:center">Unable to display Instagram feed. Please check your account has been correctly setup on <a href="'.admin_url('admin.php?page=pipdig-instagram').'" style="color:red">this page</a>. This error can also occur if you have not yet published any images to Instagram or if your Instagram profile is set to Private. Only site admins can see this message.</p>';
		}
	}
}
add_action('p3_top_site_main_container', 'p3_instagram_site_main_container', 99);


// style & light feed
function p3_instagram_top_of_posts() {

	if (!is_home() || is_paged() || !get_theme_mod('body_instagram')) {
		return;
	}

	$images = p3_instagram_fetch(); // grab images

	if ($images) {
		//$num = intval(get_theme_mod('p3_instagram_number', 8));
	?>
		<div id="p3_instagram_top_of_posts">
		<h3 class="widget-title"><span>Instagram</span></h3>
			<?php for ($x = 0; $x <= 4; $x++) {
				if (!isset($images[$x]['link'])) {
					break;
				}
				$hide_class = '';
				//if ($x >= 4) {
					//$hide_class = ' p3_instagram_hide_mobile';
				//}
				?>
				<a href="<?php echo $images[$x]['link']; ?>" id="p3_instagram_post_<?php echo $x; ?>" class="p3_instagram_post<?php echo $hide_class; ?>" style="background-image:url(<?php echo $images[$x]['src']; ?>);" rel="nofollow noopener" target="_blank" aria-label="Instagram">
					<img src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABAQMAAAAl21bKAAAAA1BMVEUAAACnej3aAAAAAXRSTlMAQObYZgAAAApJREFUCNdjYAAAAAIAAeIhvDMAAAAASUVORK5CYII=" class="p3_instagram_square" alt=""/>
					<div class="p3_instagram_post_overlay">
						<?php if (get_theme_mod('p3_instagram_meta', 1) && !empty($images[$x]['likes'])) { ?>
							<span class="p3_instagram_likes"><i class="pipdigicons pipdigicons-comment"></i> <?php echo $images[$x]['comments']; ?> &nbsp;
							<i class="pipdigicons pipdigicons-heart"></i> <?php echo $images[$x]['likes']; ?></span>
						<?php } ?>
					</div>
				</a>
			<?php } ?>
			<div class="clearfix"></div>
		</div>
		<div class="clearfix"></div>
		<?php
	} else { // no access token or user id, so error for admins:
		if (current_user_can('manage_options')) {
			echo '<p style="text-align:center">Unable to display Instagram feed. Please check your account has been correctly setup on <a href="'.admin_url('admin.php?page=pipdig-instagram').'" style="color:red">this page</a>. This error can also occur if you have not yet published any images to Instagram or if your Instagram profile is set to Private. Only site admins can see this message.</p>';
		}
	}
}
add_action('p3_posts_column_start', 'p3_instagram_top_of_posts', 99);


// kensington feed
function p3_instagram_bottom_of_posts() {

	if (!get_theme_mod('p3_instagram_kensington') || (!is_front_page() && !is_home())) {
		return;
	}

	$images = p3_instagram_fetch(); // grab images

	if ($images) {

		$lazy = false;
		if (is_pipdig_lazy()) {
			$lazy = true;
		}

		$num = intval(get_theme_mod('p3_instagram_number', 8));
		if (get_theme_mod('p3_instagram_rows')) {
			$num = $num*2;
		}
	?>
		<div class="clearfix"></div>
		<div id="p3_instagram_kensington" class="row">
			<div class="container">
			<h3 class="widget-title"><span>Instagram</span></h3>
			<?php $num = $num-1; ?>
				<?php for ($x = 0; $x <= $num; $x++) {
					if (!isset($images[$x]['link'])) {
						break;
					}
					$hide_class = '';
					if ($x >= 4) {
						$hide_class = ' p3_instagram_hide_mobile';
					}
					$image_src = 'style="background-image:url('.$images[$x]['src'].');"';
					if ($lazy) {
						$hide_class .= ' pipdig_lazy';
						$image_src = 'data-src="'.$images[$x]['src'].'"';
					}
					?>
					<a href="<?php echo $images[$x]['link']; ?>" id="p3_instagram_post_<?php echo $x; ?>" class="p3_instagram_post<?php echo $hide_class; ?>" <?php echo $image_src; ?> rel="nofollow noopener" target="_blank" aria-label="Instagram">
						<img src="data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABAQMAAAAl21bKAAAAA1BMVEUAAACnej3aAAAAAXRSTlMAQObYZgAAAApJREFUCNdjYAAAAAIAAeIhvDMAAAAASUVORK5CYII=" class="p3_instagram_square" alt=""/>
						<div class="p3_instagram_post_overlay">
							<?php if (get_theme_mod('p3_instagram_meta', 1) && !empty($images[$x]['likes'])) { ?>
								<span class="p3_instagram_likes"><i class="pipdigicons pipdigicons-comment"></i> <?php echo $images[$x]['comments']; ?> &nbsp;
								<i class="pipdigicons pipdigicons-heart"></i> <?php echo $images[$x]['likes']; ?></span>
							<?php } ?>
						</div>
					</a>
				<?php } ?>
				<div class="clearfix"></div>
			</div>
		</div>
		<div class="clearfix"></div>
		<?php
	} else { // no access token or user id, so error for admins:
		if (current_user_can('manage_options')) {
			echo '<p style="text-align:center">Unable to display Instagram feed. Please check your account has been correctly setup on <a href="'.admin_url('admin.php?page=pipdig-instagram').'" style="color:red">this page</a>. This error can also occur if you have not yet published any images to Instagram or if your Instagram profile is set to Private. Only site admins can see this message.</p>';
		}
	}

}
add_action('p3_site_main_end', 'p3_instagram_bottom_of_posts', 99);


// customiser
class pipdig_p3_instagram_Customiser {
	public static function register ( $wp_customize ) {

			$wp_customize->add_section( 'pipdig_p3_instagram_section',
				array(
					'title' => 'Instagram',
					'description' => sprintf(__('Before enabling these features, you will need to add your Instagram account to <a href="%s">this page</a>.', 'p3'), admin_url( 'admin.php?page=pipdig-instagram' )),
					'capability' => 'edit_theme_options',
					'priority' => 39,
				)
			);
			
			$ig_business = false;
			$instagram_deets = get_option('pipdig_instagram');
			if (!empty($instagram_deets['user_id'])) {
				$ig_business = true;
			}

			// header feed
			$wp_customize->add_setting('p3_instagram_header',
				array(
					'default' => 0,
					'sanitize_callback' => 'absint',
				)
			);
			$wp_customize->add_control(
				'p3_instagram_header',
				array(
					'type' => 'checkbox',
					'label' => __( 'Display feed across the header (Homepage)', 'p3' ),
					'section' => 'pipdig_p3_instagram_section',
				)
			);

			// header feed on all pages?
			$wp_customize->add_setting('p3_instagram_header_all',
				array(
					'default' => 0,
					'sanitize_callback' => 'absint',
				)
			);
			$wp_customize->add_control(
				'p3_instagram_header_all',
				array(
					'type' => 'checkbox',
					'label' => __( 'Display header feed on all pages', 'p3' ),
					'description' => __( 'By default, the header feed will only display on the homepage. If you want to display it on all pages, select this option too.', 'p3' ),
					'section' => 'pipdig_p3_instagram_section',
				)
			);

			// above posts and sidebar
			$wp_customize->add_setting('p3_instagram_above_posts_and_sidebar',
				array(
					'default' => 0,
					'sanitize_callback' => 'absint',
				)
			);
			$wp_customize->add_control(
				'p3_instagram_above_posts_and_sidebar',
				array(
					'type' => 'checkbox',
					'label' => __('Display feed above posts and sidebar on homepage', 'p3'),
					'section' => 'pipdig_p3_instagram_section',
				)
			);

			// style and light
			$wp_customize->add_setting('body_instagram',
				array(
					'default' => 0,
					'sanitize_callback' => 'absint',
				)
			);
			$wp_customize->add_control(
				'body_instagram',
				array(
					'type' => 'checkbox',
					'label' => __('Display feed above posts on homepage', 'p3'),
					'section' => 'pipdig_p3_instagram_section',
				)
			);

			// kensington
			$wp_customize->add_setting('p3_instagram_kensington',
				array(
					'default' => 0,
					'sanitize_callback' => 'absint',
				)
			);
			$wp_customize->add_control(
				'p3_instagram_kensington',
				array(
					'type' => 'checkbox',
					'label' => __('Display feed below posts on homepage', 'p3'),
					'section' => 'pipdig_p3_instagram_section',
				)
			);

			// footer feed
			$wp_customize->add_setting('p3_instagram_footer',
				array(
					'default' => 0,
					'sanitize_callback' => 'absint',
				)
			);
			$wp_customize->add_control(
				'p3_instagram_footer',
				array(
					'type' => 'checkbox',
					'label' => __( 'Display feed across the footer', 'p3' ),
					'section' => 'pipdig_p3_instagram_section',
				)
			);


			// Number of images to display in instagram feed
			$wp_customize->add_setting( 'p3_instagram_number', array(
				'default' => 8,
				'sanitize_callback' => 'absint',
				)
			);
			$wp_customize->add_control( 'p3_instagram_number', array(
				'type' => 'number',
				'label' => __('Number of images to display:', 'p3'),
				'section' => 'pipdig_p3_instagram_section',
				'input_attrs' => array(
					'min' => 4,
					'max' => 10,
					'step' => 1,
					),
				)
			);

			// 2 rows?
			$wp_customize->add_setting('p3_instagram_rows',
				array(
					'default' => 0,
					'sanitize_callback' => 'absint',
				)
			);
			$wp_customize->add_control(
				'p3_instagram_rows',
				array(
					'type' => 'checkbox',
					'label' => __( 'Display feed in 2 rows', 'p3' ),
					'section' => 'pipdig_p3_instagram_section',
				)
			);

			// footer feed title
			$wp_customize->add_setting('p3_instagram_footer_title',
				array(
					'default' => 0,
					'sanitize_callback' => 'absint',
				)
			);
			$wp_customize->add_control(
				'p3_instagram_footer_title',
				array(
					'type' => 'checkbox',
					'label' => __( 'Display title above footer feed', 'p3' ),
					'section' => 'pipdig_p3_instagram_section',
				)
			);

			// show likes/comments on hover
			if ($ig_business) {
				$wp_customize->add_setting('p3_instagram_meta', 1,
					array(
						'default' => 1,
						'sanitize_callback' => 'absint',
					)
				);
				$wp_customize->add_control(
					'p3_instagram_meta',
					array(
						'type' => 'checkbox',
						'label' => __( 'Display Comments & Likes count on hover', 'p3' ),
						'section' => 'pipdig_p3_instagram_section',
					)
				);
			}


			//  Post overlay background color
			$wp_customize->add_setting('p3_instagram_hover_bg',
				array(
					'default' => '',
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'p3_instagram_hover_bg',
				array(
					'label' => 'Hover color',
					'section' => 'pipdig_p3_instagram_section',
					'settings' => 'p3_instagram_hover_bg',
				)
				)
			);

			//  Post overlay text color
			$wp_customize->add_setting('p3_instagram_hover_text',
				array(
					'default' => '',
					'sanitize_callback' => 'sanitize_hex_color',
				)
			);
			$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'p3_instagram_hover_text',
				array(
					'label' => 'Hover text color',
					'section' => 'pipdig_p3_instagram_section',
					'settings' => 'p3_instagram_hover_text',
				)
				)
			);

			$wp_customize->add_setting('p3_instagram_hover_opacity',
				array(
					'default' => 80,
					'sanitize_callback' => 'absint',
				)
			);
			$wp_customize->add_control( 'p3_instagram_hover_opacity', array(
				'type' => 'range',
				'section' => 'pipdig_p3_instagram_section',
				'label' => 'Hover color opacity',
				'input_attrs' => array(
					'min' => 1,
					'max' => 95,
					'step' => 5,
					),
				)
			);


		}
}
add_action( 'customize_register' , array( 'pipdig_p3_instagram_Customiser' , 'register' ) );

function p3_instagram_styles() {

	$styles = '';

	$p3_instagram_hover_bg = get_theme_mod('p3_instagram_hover_bg');
	$p3_instagram_hover_text = get_theme_mod('p3_instagram_hover_text');
	$p3_instagram_hover_opacity = absint(get_theme_mod('p3_instagram_hover_opacity', 80));

	if ($p3_instagram_hover_bg) {
		list($r, $g, $b) = sscanf($p3_instagram_hover_bg, "#%02x%02x%02x");
		$styles .= ".p3_instagram_post_overlay { background: rgba($r, $g, $b, .$p3_instagram_hover_opacity); }";
	}

	if ($p3_instagram_hover_text) {
		$styles .= '.p3_instagram_post .p3_instagram_likes { color: '.$p3_instagram_hover_text.' }';
	}


	if ($styles) {
		echo '<style>'.strip_tags($styles).'</style>';
	}


}
add_action( 'wp_head', 'p3_instagram_styles' );
